@@ -17,7 +17,7 @@ use File::Basename;
 
 if ($ARGV[0] eq '--version') {
     print basename($0) . ": $0\n",
-        "build: 4.92\n",
+        "build: 4.94.2\n",
         "perl(runtime): $]\n";
         exit 0;
 }
